Class: Google::Apis::ArtifactregistryV1beta1::ArtifactRegistryService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/artifactregistry_v1beta1/service.rb

Overview

Artifact Registry API

Store and manage build artifacts in a scalable and integrated service built on Google infrastructure.

Examples:

require 'google/apis/artifactregistry_v1beta1'

Artifactregistry = Google::Apis::ArtifactregistryV1beta1 # Alias the module
service = Artifactregistry::ArtifactRegistryService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://artifactregistry.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeArtifactRegistryService

Returns a new instance of ArtifactRegistryService.



48
49
50
51
52
53
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 48

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-artifactregistry_v1beta1',
        client_version: Google::Apis::ArtifactregistryV1beta1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



41
42
43
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 41

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



46
47
48
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 46

def quota_user
  @quota_user
end

Instance Method Details

#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation

Creates a repository. The returned Operation will finish once the repository has been created. Its response will be the created Repository.

Parameters:

  • parent (String)

    Required. The name of the parent resource where the repository will be created.

  • repository_object (Google::Apis::ArtifactregistryV1beta1::Repository) (defaults to: nil)
  • repository_id (String) (defaults to: nil)

    Required. The repository id to use for this repository.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 196

def create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/repositories', options)
  command.request_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation
  command.request_object = repository_object
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['repositoryId'] = repository_id unless repository_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag

Creates a tag.

Parameters:

  • parent (String)

    The name of the parent resource where the tag will be created.

  • tag_object (Google::Apis::ArtifactregistryV1beta1::Tag) (defaults to: nil)
  • tag_id (String) (defaults to: nil)

    The tag id to use for this repository.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



683
684
685
686
687
688
689
690
691
692
693
694
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 683

def create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/tags', options)
  command.request_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation
  command.request_object = tag_object
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Tag
  command.params['parent'] = parent unless parent.nil?
  command.query['tagId'] = tag_id unless tag_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation

Deletes a repository and all of its contents. The returned Operation will finish once the repository has been deleted. It will not have any Operation metadata and will return a google.protobuf.Empty response.

Parameters:

  • name (String)

    Required. The name of the repository to delete.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



231
232
233
234
235
236
237
238
239
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 231

def delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation

Deletes a package and all of its versions and tags. The returned operation will complete once the package has been deleted.

Parameters:

  • name (String)

    Required. The name of the package to delete.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



581
582
583
584
585
586
587
588
589
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 581

def delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Empty

Deletes a tag.

Parameters:

  • name (String)

    The name of the tag to delete.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



716
717
718
719
720
721
722
723
724
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 716

def delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Empty::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation

Deletes a version and all of its content. The returned operation will complete once the version has been deleted.

Parameters:

  • name (String)

    The name of the version to delete.

  • force (Boolean) (defaults to: nil)

    By default, a version that is tagged may not be deleted. If force=true, the version and any tags pointing to the version are deleted.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



876
877
878
879
880
881
882
883
884
885
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 876

def delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['force'] = force unless force.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Location

Gets information about a location.

Parameters:

  • name (String)

    Resource name for the location.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



75
76
77
78
79
80
81
82
83
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 75

def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Location::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Location
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



162
163
164
165
166
167
168
169
170
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 162

def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Repository

Gets a repository.

Parameters:

  • name (String)

    Required. The name of the repository to retrieve.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



261
262
263
264
265
266
267
268
269
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 261

def get_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Repository
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::File

Gets a file.

Parameters:

  • name (String)

    Required. The name of the file to retrieve.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



484
485
486
487
488
489
490
491
492
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 484

def get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::File::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::File
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Policy

Gets the IAM policy for a given resource.

Parameters:

  • resource (String)

    REQUIRED: The resource for which the policy is being requested. See Resource names for the appropriate value for this field.

  • options_requested_policy_version (Fixnum) (defaults to: nil)

    Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the IAM documentation.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



304
305
306
307
308
309
310
311
312
313
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 304

def get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Policy::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Policy
  command.params['resource'] = resource unless resource.nil?
  command.query['options.requestedPolicyVersion'] = options_requested_policy_version unless options_requested_policy_version.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Package

Gets a package.

Parameters:

  • name (String)

    Required. The name of the package to retrieve.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



611
612
613
614
615
616
617
618
619
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 611

def get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Package::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Package
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag

Gets a tag.

Parameters:

  • name (String)

    The name of the tag to retrieve.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



746
747
748
749
750
751
752
753
754
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 746

def get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Tag
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Version

Gets a version

Parameters:

  • name (String)

    The name of the version to retrieve.

  • view (String) (defaults to: nil)

    The view that should be returned in the response.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



909
910
911
912
913
914
915
916
917
918
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 909

def get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Version::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Version
  command.params['name'] = name unless name.nil?
  command.query['view'] = view unless view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse

Lists repositories.

Parameters:

  • parent (String)

    Required. The name of the parent resource whose repositories will be listed.

  • order_by (String) (defaults to: nil)

    Optional. The field to order the results by.

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of repositories to return. Maximum page size is 1,000.

  • page_token (String) (defaults to: nil)

    The next_page_token value returned from a previous list request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 341

def list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/repositories', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListFilesResponse

Lists files.

Parameters:

  • parent (String)

    Required. The name of the repository whose files will be listed. For example: " projects/p1/locations/us-central1/repositories/repo1

  • filter (String) (defaults to: nil)

    An expression for filtering the results of the request. Filter rules are case insensitive. The fields eligible for filtering are: * name * owner * annotations Examples of using a filter: To filter the results of your request to files with the name my_file.txt in project my-project in the us- central region, in repository my-repo, append the following filter expression to your request: * name="projects/my-project/locations/us-central1/ repositories/my-repo/files/my-file.txt" You can also use wildcards to match any number of characters before or after the value: * name="projects/my- project/locations/us-central1/repositories/my-repo/files/my-*" * name=" projects/my-project/locations/us-central1/repositories/my-repo/files/*file.txt" * name="projects/my-project/locations/us-central1/repositories/my-repo/ files/*file*" To filter the results of your request to files owned by the version 1.0 in package pkg1, append the following filter expression to your request: * owner="projects/my-project/locations/us-central1/repositories/ my-repo/packages/my-package/versions/1.0" To filter the results of your request to files with the annotation key-value pair [external_link: external_link_value], append the following filter expression to your request:

    • "annotations.external_link:external_link_value" To filter just for a specific annotation key external_link, append the following filter expression to your request: * "annotations.external_link" If the annotation key or value contains special characters, you can escape them by surrounding the value with backticks. For example, to filter the results of your request to files with the annotation key-value pair [external.link:https://example. com/my-file], append the following filter expression to your request: * " annotations.`external.link`:`https://example.com/my-file`" You can also filter with annotations with a wildcard to match any number of characters before or after the value: * "annotations.*_link:`*example.com*`"
  • page_size (Fixnum) (defaults to: nil)

    The maximum number of files to return. Maximum page size is 1,000.

  • page_token (String) (defaults to: nil)

    The next_page_token value returned from a previous list request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



547
548
549
550
551
552
553
554
555
556
557
558
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 547

def list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/files', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListFilesResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::ListFilesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListTagsResponse

Lists tags.

Parameters:

  • parent (String)

    The name of the parent package whose tags will be listed. For example: projects/p1/locations/us-central1/repositories/repo1/packages/pkg1.

  • filter (String) (defaults to: nil)

    An expression for filtering the results of the request. Filter rules are case insensitive. The fields eligible for filtering are: * name * version Examples of using a filter: To filter the results of your request to tags with the name my-tag in package my-package in repository my-repo in project " y-project in the us-central region, append the following filter expression to your request: * name="projects/my-project/locations/us-central1/repositories/ my-repo/packages/my-package/tags/my-tag" You can also use wildcards to match any number of characters before or after the value: * name="projects/my- project/locations/us-central1/repositories/my-repo/packages/my-package/tags/my* " * name="projects/my-project/locations/us-central1/repositories/my-repo/ packages/my-package/tags/*tag" * name="projects/my-project/locations/us- central1/repositories/my-repo/packages/my-package/tags/*tag*" To filter the results of your request to tags applied to the version 1.0 in package my- package, append the following filter expression to your request: * version=" projects/my-project/locations/us-central1/repositories/my-repo/packages/my- package/versions/1.0"

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of tags to return. Maximum page size is 1,000.

  • page_token (String) (defaults to: nil)

    The next_page_token value returned from a previous list request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



798
799
800
801
802
803
804
805
806
807
808
809
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 798

def list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/tags', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListTagsResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::ListTagsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse

Lists versions.

Parameters:

  • parent (String)

    The name of the parent resource whose versions will be listed.

  • order_by (String) (defaults to: nil)

    Optional. The field to order the results by.

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of versions to return. Maximum page size is 1,000.

  • page_token (String) (defaults to: nil)

    The next_page_token value returned from a previous list request, if any.

  • view (String) (defaults to: nil)

    The view that should be returned in the response.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



948
949
950
951
952
953
954
955
956
957
958
959
960
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 948

def list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/versions', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['view'] = view unless view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse

Lists packages.

Parameters:

  • parent (String)

    Required. The name of the parent resource whose packages will be listed.

  • order_by (String) (defaults to: nil)

    Optional. The field to order the results by.

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of packages to return. Maximum page size is 1,000.

  • page_token (String) (defaults to: nil)

    The next_page_token value returned from a previous list request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 647

def list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/packages', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse

Lists information about the supported locations for this service. This method lists locations based on the resource scope provided in the [ ListLocationsRequest.name] field: * Global locations: If name is empty, the method lists the public locations available to all projects. * Project- specific locations: If name follows the format projects/project`, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project. For gRPC and client library implementations, the resource name is passed as thename` field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Parameters:

  • name (String)

    The resource that owns the locations collection, if applicable.

  • extra_location_types (Array<String>, String) (defaults to: nil)

    Optional. Do not use this field. It is unsupported and is ignored unless explicitly documented otherwise. This is primarily for internal usage.

  • filter (String) (defaults to: nil)

    A filter to narrow down results to a preferred subset. The filtering language accepts strings like "displayName=tokyo", and is documented in more detail in AIP-160.

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of results to return. If not set, the service selects a default.

  • page_token (String) (defaults to: nil)

    A page token received from the next_page_token field in the response. Send that page token to receive the subsequent page.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 127

def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}/locations', options)
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse
  command.params['name'] = name unless name.nil?
  command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Repository

Updates a repository.

Parameters:

  • name (String)

    The name of the repository, for example: projects/p1/locations/us-central1/ repositories/repo1. For each location in a project, repository names must be unique.

  • repository_object (Google::Apis::ArtifactregistryV1beta1::Repository) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    The update mask applies to the resource. For the FieldMask definition, see https://developers.google.com/protocol-buffers/docs/reference/google.protobuf# fieldmask

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 381

def patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1beta1/{+name}', options)
  command.request_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation
  command.request_object = repository_object
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Repository
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag

Updates a tag.

Parameters:

  • name (String)

    The name of the tag, for example: "projects/p1/locations/us-central1/ repositories/repo1/packages/pkg1/tags/tag1". If the package part contains slashes, the slashes are escaped. The tag part can only have characters in [a- zA-Z0-9-._~:@], anything else must be URL encoded.

  • tag_object (Google::Apis::ArtifactregistryV1beta1::Tag) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    The update mask applies to the resource. For the FieldMask definition, see https://developers.google.com/protocol-buffers/docs/reference/google.protobuf# fieldmask

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



839
840
841
842
843
844
845
846
847
848
849
850
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 839

def patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1beta1/{+name}', options)
  command.request_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation
  command.request_object = tag_object
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Tag
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Policy

Updates the IAM policy for a given resource.

Parameters:

  • resource (String)

    REQUIRED: The resource for which the policy is being specified. See Resource names for the appropriate value for this field.

  • set_iam_policy_request_object (Google::Apis::ArtifactregistryV1beta1::SetIamPolicyRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



417
418
419
420
421
422
423
424
425
426
427
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 417

def set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', options)
  command.request_representation = Google::Apis::ArtifactregistryV1beta1::SetIamPolicyRequest::Representation
  command.request_object = set_iam_policy_request_object
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::Policy::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::Policy
  command.params['resource'] = resource unless resource.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse

Tests if the caller has a list of permissions on a resource.

Parameters:

  • resource (String)

    REQUIRED: The resource for which the policy detail is being requested. See Resource names for the appropriate value for this field.

  • test_iam_permissions_request_object (Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



452
453
454
455
456
457
458
459
460
461
462
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 452

def test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', options)
  command.request_representation = Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsRequest::Representation
  command.request_object = test_iam_permissions_request_object
  command.response_representation = Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse::Representation
  command.response_class = Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse
  command.params['resource'] = resource unless resource.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end