Class: Google::Apis::ArtifactregistryV1beta1::ArtifactRegistryService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ArtifactregistryV1beta1::ArtifactRegistryService
- Defined in:
- lib/google/apis/artifactregistry_v1beta1/service.rb
Overview
Artifact Registry API
Store and manage build artifacts in a scalable and integrated service built on Google infrastructure.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://artifactregistry.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Creates a repository.
-
#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag
Creates a tag.
-
#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Deletes a repository and all of its contents.
-
#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Deletes a package and all of its versions and tags.
-
#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Empty
Deletes a tag.
-
#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Deletes a version and all of its content.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Repository
Gets a repository.
-
#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::File
Gets a file.
-
#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Policy
Gets the IAM policy for a given resource.
-
#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Package
Gets a package.
-
#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag
Gets a tag.
-
#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Version
Gets a version.
-
#initialize ⇒ ArtifactRegistryService
constructor
A new instance of ArtifactRegistryService.
-
#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse
Lists repositories.
-
#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListFilesResponse
Lists files.
-
#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListTagsResponse
Lists tags.
-
#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse
Lists versions.
-
#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse
Lists packages.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Repository
Updates a repository.
-
#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag
Updates a tag.
-
#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Policy
Updates the IAM policy for a given resource.
-
#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse
Tests if the caller has a list of permissions on a resource.
Constructor Details
#initialize ⇒ ArtifactRegistryService
Returns a new instance of ArtifactRegistryService.
48 49 50 51 52 53 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-artifactregistry_v1beta1', client_version: Google::Apis::ArtifactregistryV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Creates a repository. The returned Operation will finish once the repository has been created. Its response will be the created Repository.
191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 191 def create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/repositories', ) command.request_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation command.request_object = repository_object command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['repositoryId'] = repository_id unless repository_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag
Creates a tag.
678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 678 def create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/tags', ) command.request_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation command.request_object = tag_object command.response_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Tag command.params['parent'] = parent unless parent.nil? command.query['tagId'] = tag_id unless tag_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Deletes a repository and all of its contents. The returned Operation will finish once the repository has been deleted. It will not have any Operation metadata and will return a google.protobuf.Empty response.
226 227 228 229 230 231 232 233 234 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 226 def delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Deletes a package and all of its versions and tags. The returned operation will complete once the package has been deleted.
576 577 578 579 580 581 582 583 584 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 576 def delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Empty
Deletes a tag.
711 712 713 714 715 716 717 718 719 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 711 def delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Empty::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Deletes a version and all of its content. The returned operation will complete once the version has been deleted.
871 872 873 874 875 876 877 878 879 880 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 871 def delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Location::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
157 158 159 160 161 162 163 164 165 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 157 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Repository
Gets a repository.
256 257 258 259 260 261 262 263 264 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 256 def get_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Repository command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::File
Gets a file.
479 480 481 482 483 484 485 486 487 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 479 def get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::File::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::File command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Policy
Gets the IAM policy for a given resource.
299 300 301 302 303 304 305 306 307 308 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 299 def get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Policy::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Package
Gets a package.
606 607 608 609 610 611 612 613 614 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 606 def get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Package::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Package command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag
Gets a tag.
741 742 743 744 745 746 747 748 749 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 741 def get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Tag command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Version
Gets a version
904 905 906 907 908 909 910 911 912 913 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 904 def get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::Version::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Version command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse
Lists repositories.
336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 336 def list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/repositories', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::ListRepositoriesResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListFilesResponse
Lists files.
542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 542 def list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/files', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListFilesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::ListFilesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListTagsResponse
Lists tags.
793 794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 793 def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/tags', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListTagsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::ListTagsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse
Lists versions.
943 944 945 946 947 948 949 950 951 952 953 954 955 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 943 def list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/versions', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::ListVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse
Lists packages.
642 643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 642 def list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/packages', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::ListPackagesResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 122 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Repository
Updates a repository.
376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 376 def patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation command.request_object = repository_object command.response_representation = Google::Apis::ArtifactregistryV1beta1::Repository::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Repository command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Tag
Updates a tag.
834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 834 def patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation command.request_object = tag_object command.response_representation = Google::Apis::ArtifactregistryV1beta1::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Tag command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::Policy
Updates the IAM policy for a given resource.
412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 412 def set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ArtifactregistryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta1::Policy::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse
Tests if the caller has a list of permissions on a resource.
447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/google/apis/artifactregistry_v1beta1/service.rb', line 447 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |